@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-hide-drawers" "2.0.0"
+(define-package "org-hide-drawers" "20250924.732"
   "Hide drawers in Org using overlays."
   '((emacs "26.1"))
   :url "https://github.com/krisbalintona/org-hide-drawers.git"
